#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'beautiful_url/class/generate_tab_completion_for_bash_shell.rb'
# =========================================================================== #
module BeautifulUrl

class BeautifulUrl # It is part of the class.

  begin
    require 'save_file'
  rescue LoadError; end

  # ========================================================================= #
  # === generate_tab_completion_for_bash_shell
  #
  # This entry point will generate the tab-completion for the BASH shell.
  #
  # Invocation examples:
  #
  #   purl GENERATE
  #   purl --generate
  #
  # ========================================================================= #
  def generate_tab_completion_for_bash_shell
    begin
      require 'collect_first_word_of_case_menu'
    rescue LoadError; end
    begin
      require 'opn'
    rescue LoadError; end
    opn; e 'Now generating tab completion for the bash shell.'
    _ = ''.dup # This is the string to store.
    _ << 'completion_for_purl()
{
  local cur complete_these_words
  
  COMPREPLY=() # Array variable storing the possible completions.
  cur="${COMP_WORDS[COMP_CWORD]}"
  complete_these_words="'
    beautiful_menu = ::BeautifulUrl[:beautiful_menu]
    if beautiful_menu.is_a? Array
      beautiful_menu = beautiful_menu.first
    end
    results = CollectFirstWordOfCaseMenu.new(beautiful_menu).result
    results.sort.each {|entry|
      _ << entry+"\n"
    }
    _ << ' "

  if [[ ${cur} == * ]] ; then
    COMPREPLY=( $(compgen -W "${complete_these_words}" -- ${cur}) )
    return 0
  fi
}
# Next, available auto-completion for the commands "purl" and "url".
complete -F completion_for_purl url
complete -F completion_for_purl purl
'
    store_where =
      "#{BASE_DIR}DATA/PC/OS/LINUX/SHELL/SCRIPTS/completion_for_purl.sh"
    opn; e 'We will store at `'+store_where+'`.'
    SaveFile.write_what_into(_, store_where)
  end; alias generate_tab_completion generate_tab_completion_for_bash_shell # === generate_tab_completion

end; end # bmenu