#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === BeautifulUrl::BeautifulUrl
#
# The class BeautifulUrl wants to make it easier to open local pages -
# but it can also make use of shortcuts for remote files.
#
# It additionally supports the usage of intralinks, e.g. if you wish
# to append something like '#foo' to a html page, it is possible
# through this project.
#
# See below for some specific usage examples.
#
# In the event that a substitute for the given input can not be found,
# we will return the original input unmodified.
#
# Specific usage examples for class BeautifulUrl in ruby code:
#
#   require 'beautiful_url'
#   url = BeautifulUrl.new('science_news')
#   url.input?; url.url?; url.remote?
#   url.do_replace_localhost
#   url.replace_data
#   x = BeautifulUrl.new 'geastask'
#   BeautifulUrl.new('slogans').url?
#   BeautifulUrl.new('geastask').url_was_found
#   BeautifulUrl.new('cmd#chroot') # => "http://localhost/DATA/PC/OS/LINUX/LINUX_COMMANDS.cgi#chroot"
#
# =========================================================================== #
# require 'beautiful_url/class/initialize.rb'
# =========================================================================== #
require 'beautiful_url/class/constants.rb'
require 'beautiful_url/class/misc.rb'
require 'beautiful_url/class/reset.rb'
require 'beautiful_url/class/run.rb'

module BeautifulUrl

class BeautifulUrl # === BeautifulUrl::BeautifulUrl

  alias e puts

  # ========================================================================= #
  # === initialize
  #
  # Usage examples:
  #
  #   x = BeautifulUrl::BeautifulUrl.new('palemoon', :replace_localhost)
  #   x = BeautifulUrl::BeautifulUrl.new('palemoon' {{ replace_localhost: true }}
  #
  # ========================================================================= #
  def initialize(
      commandline_arguments = ARGV,
      run_already           = RUN_ALREADY,
      &block
    )
    reset # Must come first.
    case commandline_arguments # case tag
    # ======================================================================= #
    # === :dont_run_yet
    # ======================================================================= #
    when :dont_run_yet,
         :do_not_run_yet
      commandline_arguments = DEFAULT_URL
      run_already = false
    end
    set_commandline_arguments(
      commandline_arguments
    )
    case run_already
    # ======================================================================= #
    # === :replace_localhost
    # ======================================================================= #
    when :replace_localhost,
         :replace,
         :replace_localhost_with_data,
         :do_replace_localhost
      @replace_localhost_with_data = true # Default, as this is more important.
      run_already = RUN_ALREADY
    else
      if run_already.is_a? Hash # Must come after reset().
        # =================================================================== #
        # === :replace_localhost
        # =================================================================== #
        if run_already.has_key? :replace_localhost
          @replace_localhost_with_data = run_already[:replace_localhost]
          run_already = RUN_ALREADY # Restore the default again. 
        # =================================================================== #
        # === :replace
        # =================================================================== #
        elsif run_already.has_key? :replace
          @replace_localhost_with_data = run_already[:replace]
          run_already = RUN_ALREADY # Restore the default again.
        end
      end
    end
    # ======================================================================= #
    # === Handle blocks given to us
    #
    # This has to occur before run() is called.
    # ======================================================================= #
    if block_given?
      yielded = yield
      case yielded
      # ===================================================================== #
      # === :do_not_replace_the_localhost
      # ===================================================================== #
      when :do_not_replace_the_localhost
        # In this case do nothing.
      # ===================================================================== #
      # ===:replace_localhost
      # ===================================================================== #
      when :replace_localhost
        @replace_localhost_with_data = true
      end
    end
    run if run_already
  end

end; end

if __FILE__ == $PROGRAM_NAME
  _ = BeautifulUrl::BeautifulUrl.new(ARGV)
  pp _
  puts _.return_corresponding_entry
  _.get_rid_of_localhost
  puts _.return_corresponding_entry
end # rb initialize.rb rubyreddit
    # rb initialize.rb palemoon
    # Testing this class next:
    #   purl diepasst
    #   purl pc 
    #   purl anmeldung
    #   purl pc replace
    #   purl GENERATE
    #   purl science_news
    #   burl ruby#windows
    #   burl std#amino_acids
    #   burl cmd cat
    #   burl scinews
    #   burl gobodist_homepage
    #   sani geastask
    #   purl GENERATE
    #   burl gobodist
    #   burl gobodist#Compile
    #   burl local_php#test
    #   burl stdk#Periodensystem