#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'beautiful_url/constants/base_constants.rb'
# =========================================================================== #
module BeautifulUrl

  # ========================================================================= #
  # === Constants tag. 
  #
  # Use these constants to define the base layout of the host system.
  #
  # This evidently defaults to my use case, but I will try to adapt the
  # project to be more flexible for other users as well, in the long
  # run.
  # ========================================================================= #

  # ========================================================================= #
  # === BASE_DIR
  # ========================================================================= #
  BASE_DIR = '/home/x/'
    HOME_X = BASE_DIR # === HOME_X

  # ========================================================================= #
  # === DATA_DIR
  #
  # Note that the very useful convention for the constants here is to
  # KEEP a trailing /.
  #
  # On my home system this will default to '/home/x/DATA/'.
  # ========================================================================= #
  DATA_DIR = "#{BASE_DIR}data/" # Can't use ENV here as ENV is not
                                # always available.
  # ========================================================================= #
  # === MY_DATA
  # ========================================================================= #
  MY_DATA = DATA_DIR

  # ========================================================================= #
  # === DATA_IMAGES_ROEBE
  # ========================================================================= #
  DATA_IMAGES_ROEBE = "#{MY_DATA}images/roebe/"

  # ========================================================================= #
  # === MY_DATA_DIR
  # ========================================================================= #
  MY_DATA_DIR = DATA_DIR

  # ========================================================================= #
  # === DATA_RUBY_SRC
  # ========================================================================= #
  DATA_RUBY_SRC = "#{BASE_DIR}programming/ruby/src/"

  # ========================================================================= #
  # === IMG TAG
  # ========================================================================= #  
  IMG = "#{DATA_DIR}images/"

  # ========================================================================= #
  # === PROGL
  # ========================================================================= #
  PROGL                 = "#{BASE_DIR}programming/"
    # ======================================================================= #
    # === PROGRAMMING_LANGUAGES
    # ======================================================================= #
    PROGRAMMING_LANGUAGES = PROGL # Alias to the ^^^ above.
    # ======================================================================= #
    # === PROGRAMMING
    # ======================================================================= #
    PROGRAMMING           = PROGRAMMING_LANGUAGES

  # ========================================================================= #
  # === RUBY
  #
  # This constant refers to where I keep my ruby code.
  # ========================================================================= #
  RUBY                  = "#{PROGRAMMING_LANGUAGES}ruby/"

  # ========================================================================= #
  # === RUBY_SRC
  # ========================================================================= #
  RUBY_SRC              = "#{RUBY}src/"
    RSRC                = RUBY_SRC

  # ========================================================================= #
  # The following constants are all relative to LOCAL_HOST
  # ========================================================================= #

  # ========================================================================= #
  # === LHOST
  # ========================================================================= #
  LHOST                 = 'http://localhost/data/' # This is the LOCAL_HOST constant.
    # ======================================================================= #
    # === DATA
    # ======================================================================= #
    DATA = LHOST # An "alias" to the above ^^^.

  # ========================================================================= #
  # === SRC
  # ========================================================================= #
  SRC                   = "#{BASE_DIR}src"

  # ========================================================================= #
  # === PC
  # ========================================================================= #
  PC                    = "#{LHOST}PC/"

  # ========================================================================= #
  # === HARDWARE
  # ========================================================================= #
  HARDWARE              = "#{PC}hardware/"

  # ========================================================================= #
  # === PC_YAML
  # ========================================================================= #
  PC_YAML               = "#{PC}yaml/"

  # ========================================================================= #
  # === OS
  # ========================================================================= #
  OS                    = "#{PC}OS/"

  # ========================================================================= #
  # === MISC
  # ========================================================================= #
  MISC                  = "#{LHOST}misc/"

  # ========================================================================= #
  # === CSS
  # ========================================================================= #
  CSS                   = "#{LHOST}CSS/"

  # ========================================================================= #
  # === RPG
  # ========================================================================= #
  RPG                   = "#{LHOST}rpg/"

  # ========================================================================= #
  # === MUDS
  # ========================================================================= #
  MUDS                  = "#{RPG}MUDS/"
    MUD                 = MUDS # === MUD

  # ========================================================================= #
  # === STUDIUM
  # ========================================================================= #
  STUDIUM               = "#{BASE_DIR}/studium/"

  # ========================================================================= #
  # === SCI
  # ========================================================================= #
  SCI                   = "#{LHOST}science/"
  SCIENCE               = SCI   # Alias to the ^^^ above.

  # ========================================================================= #
  # === GAMES
  # ========================================================================= #
  GAMES                 = "#{LHOST}games/"

  # ========================================================================= #
  # === AUDIO
  # ========================================================================= #
  AUDIO                 = "#{LHOST}AUDIO/"

  # ========================================================================= #
  # === AUDIO_YAML
  # ========================================================================= #
  AUDIO_YAML            = "#{AUDIO}yaml/"

  # ========================================================================= #
  # === VIDEO
  # ========================================================================= #
  VIDEO                 = "#{LHOST}video/"

  # ========================================================================= #
  # === LINUX
  # ========================================================================= #
  LINUX                 = "#{PC}OS/LINUX/"

  # ========================================================================= #
  # === LINUX_YAML
  # ========================================================================= #
  LINUX_YAML            = "#{LINUX}yaml/"
  
  # ========================================================================= #
  # === BIOINFORMATIC
  # ========================================================================= #
  BIOINFORMATIC         = "#{SCI}BIOINFORMATIK/"

  # ========================================================================= #
  # === BIOLANG_DIR
  # ========================================================================= #
  BIOLANG_DIR           = "#{SCI}BIOLOGY/"

  # ========================================================================= #
  # === RUBY_DOCUMENTATION
  # ========================================================================= #
  RUBY_DOCUMENTATION    = RUBY+'documentation/'
  COOKBOOK_DIR          = PC+'COOKBOOKS/YAML/' # ALL_COOKBOOKS
  DATABASES             = PC+'DATABASES/'
  IRC                   = PC+'IRC/'
  PHP                   = PROGL+'php/'
  PERL                  = PROGL+'perl/'
  
  # ========================================================================= #
  # === RUBY_SYS
  # ========================================================================= #
  RUBY_SYS              = RUBY_SRC+'sys/'
  RUBY_WWW              = RUBY_SRC+'www/'
  RUBY_TOOLS            = RUBY_SRC+'tools/'

  # ========================================================================= #
  # === RUBY_RBT
  # ========================================================================= #
  RUBY_RBT              = RUBY_SRC+'rbt/lib/rbt/'
    RUBY_BT               = RUBY_RBT

  # ========================================================================= #
  # === RUBY_DIA
  # ========================================================================= #
  RUBY_DIA              = RUBY_SRC+'roebe/lib/roebe/shell/'

  # ========================================================================= #
  # === BEAUTIFUL_URL
  # ========================================================================= #
  BEAUTIFUL_URL         = RUBY_TOOLS+'beautiful_url/lib/beautiful_url/'
  MASTER_PIPE           = "#{RUBY_SRC}pipe_handler/lib/pipe_handler/"

  # ========================================================================= #
  # === RUBY_CYBERWEB
  # ========================================================================= #
  RUBY_CYBERWEB         = "#{RUBY_SRC}cyberweb/lib/cyberweb/"
    # ======================================================================= #
    # === CYBERWEB
    # ======================================================================= #
    CYBERWEB              = RUBY_CYBERWEB

  # ========================================================================= #
  # === IMG_RPG
  # ========================================================================= #
  IMG_RPG = "#{IMG}RPG/"

  # ========================================================================= #
  # === TODO_DIRECTORY
  # ========================================================================= #
  TODO_DIRECTORY = "#{MY_DATA}personal/todo/"

end