#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# This file here ensures a consistent, uniform encoding to be used
# for the whole BeautifulUrl namespace.
# =========================================================================== #
# require 'beautiful_url/constants/encoding.rb'
# =========================================================================== #
module BeautifulUrl

  # ========================================================================= #
  # === ENCODING_UNICODE
  # ========================================================================= #
  ENCODING_UNICODE = 'UTF-8'

  # ========================================================================= #
  # === ENCODING_ISO
  # ========================================================================= #
  ENCODING_ISO     = 'ISO-8859-1'

  # ========================================================================= #
  # === USE_THIS_ENCODING
  #
  # This constant specifies the main encoding to be used in the
  # BeautifulUrl namespace.
  # ========================================================================= #
  USE_THIS_ENCODING = ENCODING_UNICODE

  # ========================================================================= #
  # === BeautifulUrl.ensure_main_encoding
  #
  # his method can be used to ensure that the same base-encoding is
  # used, for a given String.
  # ========================================================================= #
  def self.ensure_main_encoding(
      i, use_this_encoding = USE_THIS_ENCODING
    )
    if i.is_a? String
      unless i.encoding.to_s.include? use_this_encoding
        i = i.force_encoding(use_this_encoding)
      end
    end
    i # Return it here anyway.
  end

end