#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# This file here shall primarily include the other menu-components.
# =========================================================================== #
# require 'beautiful_url/toplevel_methods/menu.rb'
# =========================================================================== #
module BeautifulUrl

  require 'beautiful_url/constants/constants.rb'
  require 'beautiful_url/toplevel_methods/local_menu.rb'
  require 'beautiful_url/toplevel_methods/jobs_menu.rb'
  require 'beautiful_url/toplevel_methods/misc.rb'
  require 'beautiful_url/toplevel_methods/pdf_books_menu.rb'
  require 'beautiful_url/toplevel_methods/roebe.rb'
  require 'beautiful_url/toplevel_methods/science_menu.rb'
  require 'beautiful_url/toplevel_methods/traditional_menu.rb'
  require 'beautiful_url/toplevel_methods/new_university_menu.rb'
  require 'beautiful_url/toplevel_methods/university_menu.rb'
  require 'beautiful_url/toplevel_methods/video_menu.rb'

  # ========================================================================= #
  # === BeautifulUrl.menu
  #
  # This method will return a String or an Array.
  #
  # The input is the shortcut to the entry that will be expanded.
  #
  # @return [String or Array]
  # ========================================================================= #
  def self.menu(
      i = :top
    )
    _ = i.to_s # .downcase # Keep it downcased. # No longer downcase as of February 2022.
    _ = ensure_main_encoding(_) # Use a uniform encidong.
    local_entry = local_menu(_) # Query for the local menu-entries.
    # ======================================================================= #
    # The following comparison means that we did not find anything in the
    # local menu.
    # ======================================================================= #
    if _ != local_entry
      return local_entry # Then this must be a local entry.
    end
    # ======================================================================= #
    # Next, check if we have a university entry. Since as of 20.04.2019,
    # if we are on roebe, and we have encounter a registered entry for
    # the given input then we will use that one instead.
    # ======================================================================= #
    if ::BeautifulUrl.is_on_roebe?
      begin
        require 'studium/toplevel_methods/return_remote_homepage_of_this_lecture.rb'
        if Studium.is_this_url_registered?(_)
          return Studium.return_remote_homepage_of_this_lecture(_)
        end 
      rescue LoadError
      end
    end
    # ======================================================================= #
    # Delegate towards science_menu() next:
    # ======================================================================= #
    science_entry = science_menu(_)
    if _ != science_entry
      return science_entry
    end
    # ======================================================================= #
    # Delegate towards pdf_books_menu() next:
    # ======================================================================= #
    entry = pdf_books_menu(_)
    if _ != entry
      return entry
    end
    # ======================================================================= #
    # Delegate towards video_menu() next:
    # ======================================================================= #
    video_entry = video_menu(_)
    if _ != video_entry
      return video_entry
    end
    # ======================================================================= #
    # Delegate towards new_university_menu() next:
    # ======================================================================= #
    new_university_entry = new_university_menu(_)
    if _ != new_university_entry
      return new_university_entry
    end
    # ======================================================================= #
    # Delegate towards university_menu() next:
    # ======================================================================= #
    university_entry = university_menu(_)
    if _ != university_entry
      return university_entry
    end
    # ======================================================================= #
    # Delegate towards jobs_menu() next:
    # ======================================================================= #
    jobs_entry = jobs_menu(_)
    if _ != jobs_entry
      return jobs_entry
    end
    traditional_entry = traditional_menu(_)
    if traditional_entry.is_a? Array # Improve on the Array in this case.
      traditional_entry.map! {|inner_entry|
        traditional_menu(inner_entry)
      }
      return traditional_entry  # return our assigned return value here.
    end
    if !(traditional_entry == i)
      return traditional_entry
    else
      return i
    end
  end; self.instance_eval { alias expand              menu } # === BeautifulUrl.expand
       self.instance_eval { alias url                 menu } # === BeautifulUrl.url
       self.instance_eval { alias sanitize_url        menu } # === BeautifulUrl.sanitize_url
       self.instance_eval { alias sanitize_this_input menu } # === BeautifulUrl.sanitize_this_input

end

if __FILE__ == $PROGRAM_NAME
  puts BeautifulUrl.menu
  # puts BeautifulUrl.menu('javascripttasks')
end