#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# This file will contain science-related.
# =========================================================================== #
# require 'beautiful_url/toplevel_methods/science_menu.rb'
# =========================================================================== #
module BeautifulUrl

  # ========================================================================= #
  # === BeautifulUrl.science_menu
  # ========================================================================= #
  def self.science_menu(
      i = :paper
    )
    case i.to_s # case tag, casetag

    # ======================================================================= #
    # === rf "OncologyMeetsImmunology:TheCancer-ImmunityCycle"
    # ======================================================================= #
    when /^Oncology(_|-| )?Meets(_|-| )?Immunology:?TheCancer(_|-| )?ImmunityCycle$/i,
         /^top(_|-| )?paper$/i # === rf top-paper
      'https://www.cell.com/immunity/pdf/S1074-7613(13)00296-3.pdf'
    # ======================================================================= #
    # === rf "Thucydides"
    # ======================================================================= #
    when /^Thucydides$/i
      'https://en.wikipedia.org/wiki/Thucydides'
    # ======================================================================= #
    # === rf "Trastuzumab"
    # ======================================================================= #
    when /^Trastuzumab$/i,
         /^remote(_|-| )?Trastuzumab$/i
      'https://de.wikipedia.org/wiki/Trastuzumab'
    # ======================================================================= #
    # === rf "Tom-Rapoport"
    # ======================================================================= #
    when /^Tom(_|-| )?Rapoport$/i
      'https://en.wikipedia.org/wiki/Tom_Rapoport'
    # ======================================================================= #
    # === rf "Herbert-Spencer"
    # ======================================================================= #
    when /^Herbert(_|-| )?Spencer$/i
      'https://en.wikipedia.org/wiki/Herbert_Spencer'
    # ======================================================================= #
    # === rf "How Artificial Intelligence Is Changing Science"
    # ======================================================================= #
    when /^How(_|-| )?Artificial(_|-| )?Intelligence(_|-| )?Is(_|-| )?Changing(_|-| )?Science$/i
      'https://www.quantamagazine.org/how-artificial-intelligence-is-changing-science-20190311/'
    # ======================================================================= #
    # === rf "nukes"
    # ======================================================================= #
    when /^nukes?$/i
      'https://en.wikipedia.org/wiki/Nuclear_weapon'
    # ======================================================================= #
    # === rf "aspirin"
    # ======================================================================= #
    when /^aspirin?$/i
      'https://en.wikipedia.org/wiki/Aspirin'
    # ======================================================================= #
    # === rf "fuselloviridae"
    # ======================================================================= #
    when /^fuselloviridae$/i
      'https://en.wikipedia.org/wiki/Fuselloviridae'
    # ======================================================================= #
    # === rf "nitrogenase"
    # ======================================================================= #
    when /^nitrogenase$/i
      'https://de.wikipedia.org/wiki/Nitrogenase'
    # ======================================================================= #
    # === rf "viper-database"
    # ======================================================================= #
    when /^viper(_|-| )?database$/i,
         'viper'
      'https://viperdb.org/' # http://viperdb.scripps.edu/'
    # ======================================================================= #
    # === rf "stromatolites"
    # ======================================================================= #
    when /^stromatolites?$/i,
         /^remote(_|-| )?stromatolites?$/i
      'https://en.wikipedia.org/wiki/Stromatolite'
    # ======================================================================= #
    # === rf "CRISPR"
    # ======================================================================= #
    when /^CRISPR$/i
      'https://en.wikipedia.org/wiki/CRISPR'
    # ======================================================================= #
    # === rf "Genome-wide analysis of lncRNA stability in human"
    # ======================================================================= #
    when /^Genome(_|-| )?wide(_|-| )?analysis(_|-| )?of(_|-| )?lncRNA(_|-| )?stability(_|-| )?in(_|-| )?human$/i
      'https://www.ncbi.nlm.nih.gov/pmc/articles/PMC8081339/'
    # ======================================================================= #
    # === rf "Evolutionary analysis"
    # ======================================================================= #
    when /^Evolutionary(_|-| )?analysis$/i
      'https://libgen.rs/book/index.php?md5=91ACDDBA7239BB0985757CB9E23A2F72'
    # ======================================================================= #
    # === rf LINE
    # ======================================================================= #
    when /^LINE$/
      'https://en.wikipedia.org/wiki/Long_interspersed_nuclear_element'
    # ======================================================================= #
    # === rf ibol
    # ======================================================================= #
    when /^ibol$/i
      'https://ibol.org/'
    # ======================================================================= #
    # === rf alyssa-gene-therapy
    # ======================================================================= #
    when /^Alyssa(_|-| )?gene(_|-| )?therapy$/i
      'https://www.bbc.com/news/health-63859184'
    # ======================================================================= #
    # === rf ellen-rothenberg
    # ======================================================================= #
    when /^Ellen(_|-| )?Rothenberg$/i
      'https://en.wikipedia.org/wiki/Ellen_Rothenberg_(scientist)'
    # ======================================================================= #
    # === rf robert-koch
    # ======================================================================= #
    when /^robert(_|-| )?koch$/i
      'https://de.wikipedia.org/wiki/Robert_Koch'
    # ======================================================================= #
    # === rf ehrlich-reagent
    # ======================================================================= #
    when /^ehrlich(_|-| )?reagent$/i
      'https://en.wikipedia.org/wiki/Ehrlich%27s_reagent'
    # ======================================================================= #
    # === rf "L11079.1"
    # ======================================================================= #
    when /^L11079.1$/i
      'https://www.ncbi.nlm.nih.gov/nuccore/L11079.1'
    # ======================================================================= #
    # === rf "ribbonbiolabs"
    # ======================================================================= #
    when /^ribbon(_|-| )?biolabs$/i
      'https://ribbonbiolabs.com/'
    # ======================================================================= #
    # === rf "Jules Bordet"
    # ======================================================================= #
    when /^Jules(_|-| )?Bordet$/i,
         /^Bordet$/i
      'https://en.wikipedia.org/wiki/Jules_Bordet'
    # ======================================================================= #
    # === rf "Jay Olshansky"
    # ======================================================================= #
    when /^Jay(_|-| )?Olshansky$/i
      'https://en.wikipedia.org/wiki/S._Jay_Olshansky'
    # ======================================================================= #
    # === rf "Philip Green"
    # ======================================================================= #
    when /^Philip(_|-| )?Green$/i
      'https://www.gs.washington.edu/faculty/green.htm'
    # ======================================================================= #
    # === rf "Laktat"
    # ======================================================================= #
    when /^Laktat$/i
      'https://i.imgur.com/EISGyYH.jpg'
    # ======================================================================= #
    # === rf "Alu elements: know the SINEs"
    # ======================================================================= #
    when /^Alu(_|-| )?elements:?(_|-| )?know(_|-| )?the(_|-| )?SINEs$/i
      'https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3334610/'
    # ======================================================================= #
    # === rf "Charles Janeway"
    # ======================================================================= #
    when /^Charles(_|-| )?Janeway$/i
      'https://en.wikipedia.org/wiki/Charles_Janeway'
    # ======================================================================= #
    # === rf "remote_article_lüdel_et_al"
    # ======================================================================= #
    when /^remote(_|-| )?article(_|-| )?lüdel(_|-| )?et(_|-| )?al$/i
      'https://www.mdpi.com/2073-4468/8/4/48'
    # ======================================================================= #
    # === rf glimmer
    # ======================================================================= #
    when /^glimmer/i
      'https://ccb.jhu.edu/software/glimmer/index.shtml'
    # ======================================================================= #
    # === rf "genscan"
    # ======================================================================= #
    when /^genscan$/i
      'http://hollywood.mit.edu/GENSCAN.html'
    # ======================================================================= #
    # === rf "nitrogenase"
    # ======================================================================= #
    when /^nitrogenase$/i
      'https://www.ncbi.nlm.nih.gov/gene/5326533'
    # ======================================================================= #
    # === rf "ncbi_gene"
    # ======================================================================= #
    when /^ncbi(_|-| )?gene$/i
      'https://www.ncbi.nlm.nih.gov/gene'
    # ======================================================================= #
    # === rf "remote_article_S1_protein_of_SARS_COV2_crosses_the_blood_brain_barrier_in_mice"
    #
    # Published in 2020.
    # ======================================================================= #
    when /^remote(_|-| )?article(_|-| )?S1(_|-| )?protein(_|-| )?of(_|-| )?SARS(_|-| )?COV2(_|-| )?crosses(_|-| )?the(_|-| )?blood(_|-| )?brain(_|-| )?barrier(_|-| )?in(_|-| )?mice$/i
      'https://www.nature.com/articles/s41593-020-00771-8'
    # ======================================================================= #
    # === rf "article_hydrogenase_enzymes_2016"
    # ======================================================================= #
    when /^article(_|-| )?hydrogenase(_|-| )?enzymes(_|-| )?2016$/i
      'https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5026416/'
    # ======================================================================= #
    # === rf "prosite"
    # ======================================================================= #
    when 'prosite',
         'prosit'
      'https://prosite.expasy.org/'
    # ======================================================================= #
    # === rf "protein_fasta"
    # ======================================================================= #
    when 'protein_fasta',
         'proteinfasta'
      'http://www.ebi.ac.uk/Tools/sss/fasta/'
    # ======================================================================= #
    # === rf "interpro"
    # ======================================================================= #
    when /^interpro$/i
      'https://www.ebi.ac.uk/interpro/'
    # ======================================================================= #
    # === rf "pfam"
    # ======================================================================= #
    when 'pfam'
      'https://pfam.xfam.org/'
    # ======================================================================= #
    # === rf "interpro"
    # ======================================================================= #
    when /^interpro$/i
      'https://www.ebi.ac.uk/interpro/'
    # ======================================================================= #
    # === rf "austrianova"
    # ======================================================================= #
    when /^austrianova$/i
      'https://austrianova.com/'
    # ======================================================================= #
    # === rf "kabat database"
    # ======================================================================= #
    when /^kabat(_|-| )?database$/i
      'http://www.bioinf.org.uk/abs/simkab.html'
    # ======================================================================= #
    # === rf human_chromosomes
    # ======================================================================= #
    when 'human_chromosomes',
         'human_genome'
      'https://en.wikipedia.org/wiki/Chromosome#Human_chromosomes'
    # ======================================================================= #
    # === rf pET11a
    # ======================================================================= #
    when 'pET11a'
      'http://ecoliwiki.net/colipedia/index.php/pET-11a'
    # ======================================================================= #
    # == rf "EMBOSS Cons"
    # ======================================================================= #
    when /EMBOSS(_|-| )?Cons$/i
      'https://www.ebi.ac.uk/Tools/msa/emboss_cons/'
    # ======================================================================= #
    # == rf "Harnessing Evolution"
    # ======================================================================= #
    when /Harnessing(_|-| )?Evolution$/i
      'https://www.youtube.com/watch?v=3oKCPoN44Lc'
    # ======================================================================= #
    # === rf jalview
    # ======================================================================= #
    when /^jalview$/i
      'https://www.jalview.org/'
    # ======================================================================= #
    # === rf Expresso
    # ======================================================================= #
    when /^Expresso$/i
      'https://tcoffee.crg.eu/apps/tcoffee/do:expresso'
    # ======================================================================= #
    # === rf MAFFT
    # ======================================================================= #
    when /^MAFFT$/i
      'https://mafft.cbrc.jp/alignment/server/'
    # ======================================================================= #
    # === rf "entrez_gene"
    # ======================================================================= #
    when 'entrez_gene',
         'entrezgene'
      'https://www.ncbi.nlm.nih.gov/gene'
    # ======================================================================= #
    # === rf "stealth liposomes"
    # ======================================================================= #
    when /^stealth(_|-| )?liposomes$/i
      'https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2426795/'
    # ======================================================================= #
    # === rf "biobricks"
    # ======================================================================= #
    when /^biobricks$/i
      'https://biobricks.org/'
    # ======================================================================= #
    # === rf "drew endy"
    # ======================================================================= #
    when /^drew(_|-| )?endy$/i
      'https://engineering.stanford.edu/person/drew-endy'
    # ======================================================================= #
    # === rf remote_biology
    # ======================================================================= #
    when 'remote_biology',
         'biology2',
         'biostack'
      'https://biology.stackexchange.com/'
    # ======================================================================= #
    # === rf "Dr. Alicia Jackson: Programming the Living World, DARPA BiT"
    # ======================================================================= #
    when /^Dr\.?(_|-| )?Alicia(_|-| )?Jackson\:?(_|-| )?Programming(_|-| )?the(_|-| )?Living(_|-| )?World\,?(_|-| )?DARPA(_|-| )?BiT$/i,
         /^synthetic(_|-| )?biology3$/i
      'https://www.youtube.com/watch?v=KAT4HrVBHqk'
    # ======================================================================= #
    # === rf "engineering biology"
    # ======================================================================= #
    when /^Synthetic(_|-| )?Life:(_|-| )?Could(_|-| )?We\??(_|-| )?Should(_|-| )?We\??$/i,
         /^synthetic(_|-| )?biology2$/i
      'https://www.youtube.com/watch?v=dcLG5fzP91I'
    # ======================================================================= #
    # === rf "engineering biology"
    # ======================================================================= #
    when /^engineering(_|-| )?biology$/i,
         /^synthetic(_|-| )?biology1$/i
      'https://www.youtube.com/watch?v=vcmZotjr_CU'
    # ======================================================================= #
    # === rf pleistocene_park
    # ======================================================================= #
    when /^pleistocene(-|_| )?park$/i
      'https://en.wikipedia.org/wiki/Pleistocene_Park'
    # ======================================================================= #
    # === rf remote_science
    # ======================================================================= #
    when 'remote_science',
         'standard_wissenschaft'
      'https://derstandard.at/Wissenschaft'
    # ======================================================================= #
    # === rf flybase
    # ======================================================================= #
    when /^flybase\??$/i
      'https://flybase.org/'
    # ======================================================================= #
    # === rf "Landscape of transcription in human cells"
    # ======================================================================= #
    when /Landscape of transcription in human cells/ # science
      'https://www.nature.com/articles/nature11233'
    # ======================================================================= #
    # === rf cadnano
    # ======================================================================= #
    when /^cadnano$/i
      'https://cadnano.org/'
    # ======================================================================= #
    # === rf left_dna
    # ======================================================================= #
    when /^left(-|_| )?dna$/i
      'http://users.fred.net/tds//leftdna/'
    # ======================================================================= #
    # === rf ebi
    # ======================================================================= #
    when 'ebi',
         'european_bioinformatics_institute'
      'https://www.ebi.ac.uk/'
    # ======================================================================= #
    # === rf orf_science
    # ======================================================================= #
    when 'orf_science'
      'http://sciencev1.orf.at/'
    # ======================================================================= #
    # === rf "grow-your-own-treehouse"
    # ======================================================================= #
    when /^grow(-|_| )?your(-|_| )?own(-|_| )?treehouse$/i
      'https://inhabitat.com/grow-your-own-treehouse/'
    # ======================================================================= #
    # === sandwalk
    # ======================================================================= #
    when 'sandwalk' # Guter Blogger, über Science.
      'https://sandwalk.blogspot.com/'
    # ======================================================================= #
    # === rf data_science
    # ======================================================================= #
    when 'data_science',
         'datascience',
         'data_science?'
      'https://www.google.com/trends/explore#q=data%20science'
    # ======================================================================= #
    # === rf science_news
    # ======================================================================= #
    when /science(_|-)?news/i
      'http://derstandard.at/Wissenschaft'
    # ======================================================================= #
    # === rf "scarabgenomics"
    # ======================================================================= #
    when /^scarab(-|_| )?genomics$/i
      'https://www.scarabgenomics.com/'
    # ======================================================================= #
    # === rf "coronavirus in österreich"
    # ======================================================================= #
    when /^coronavirus(-|_| )?in(-|_| )?österreich$/i
      'https://orf.at/corona/daten/bezirke'
    # ======================================================================= #
    # === rf "protein blast"
    # ======================================================================= #
    when /^protein(-|_| )?blast$/i
      'https://blast.ncbi.nlm.nih.gov/Blast.cgi?PAGE=Proteins'
    # ======================================================================= #
    # === rf "MEGA7"
    # ======================================================================= #
    when /^MEGA7$/i
      'https://www.megasoftware.net'
    # ======================================================================= #
    # === rf "PAUP"
    # ======================================================================= #
    when /^PAUP$/i
      'https://paup.phylosolutions.com/'
    # ======================================================================= #
    # === rf paper 
    # ======================================================================= #
    when 'paper'
      'https://pubmed.ncbi.nlm.nih.gov/29937223/'
    else
      return i # Must return the original input in this case.
    end
  end

end

if __FILE__ == $PROGRAM_NAME
  puts BeautifulUrl.science_menu(:paper)
end