#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === BeautifulUrl::App
#
# This class can show, on a webpage, whether a remote URL is registered
# or not. Additionally it can redirect or load up a new website.
#
# Usage example:
#
#   BeautifulUrl::App.new
#
# =========================================================================== #
# require 'beautiful_url/www/app.rb'
# BeautifulUrl::App.start_sinatra_interface
# =========================================================================== #
require 'web_object/requires/require_sinatra.rb'

module BeautifulUrl

class App < ::WebObject::Sinatra # === BeautifulUrl::App

  require 'beautiful_url'

  # ========================================================================= #
  # === before                                                     (before tag)
  # ========================================================================= #
  before {
    content_type(:html, 'charset' => 'UTF-8')
  }

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      commandline_arguments = nil,
      run_already           = true
    )
    super()
    reset
    set_commandline_arguments(
      commandline_arguments
    )
    run if run_already
  end

  # ========================================================================= #
  # === reset                                                     (reset tag)
  # ========================================================================= #
  def reset
    super()
    # ======================================================================= #
    # === @automatically_redirect_when_the_input_has_been_found
    #
    # If the next variable is set to true then we will automatically
    # redirect the visitor.
    # ======================================================================= #
    @automatically_redirect_when_the_input_has_been_found = false
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_commandline_arguments(i = '')
    i = [i].flatten.compact
    @commandline_arguments = i
  end

  # ========================================================================= #
  # === commandline_arguments?
  # ========================================================================= #
  def commandline_arguments?
    @commandline_arguments
  end

  # ========================================================================= #
  # === /
  # ========================================================================= #
  get('/*') {
    _ = params[:splat]
    route_to_this_action = '/'
    if params.has_key?('user_input')
      _ = params.fetch('user_input')
    end
    original_input = _.dup
    original_input = original_input.join(' ').strip if _.is_a? Array
    _ = ::BeautifulUrl.return_as_string(original_input)
    header = html_title('Translate URLs')+'<body>'
    footer = '</body></html>'
    form_div = div(css_style: 'padding: 0.2em') {
      form(action: route_to_this_action, id: 'beautiful_url', css_style: 'margin-left:2em; margin-top:2px') {
        '<input type="text" name="user_input" autofocus '\
        'style="padding:2px; border:3px solid slateblue; padding: 4px"><br>'+
        input_type_submit
      }
    }
    if original_input.empty?
      header+
      p(
        'Please provide an URL (shortcut).'
      )+
      form_div+
      footer
    elsif _ == original_input
      header+
      p(
        'Not found the input: <br><b>'+original_input+'</b>'
      )+
      form_div+
      footer
    else
      # In this case the input was found.
      if @automatically_redirect_when_the_input_has_been_found
        redirect _
      end
      header+
      p(
        'The original input was: <br><b style="margin-left:1em">'+original_input+'</b>'
      )+
      return_proper_link_for(_)+
      br+
      form_div+
      footer
    end
  }

  # ========================================================================= #
  # === return_proper_link_for
  # ========================================================================= #
  def return_proper_link_for(i)
    a(
      i, content: i, css_style: 'margin-left: 2em; font-weight: bold;'
    )
  end

  # ========================================================================= #
  # === html_title
  # ========================================================================= #
  def html_title(this_title = 'Translate URLs')
    "<html><title>#{this_title}</title></html>"
  end

  # ========================================================================= #
  # === run                                                         (run tag)
  # ========================================================================= #
  def run
  end

  # ========================================================================= #
  # === BeautifulUrl::App.start_sinatra_interface
  # ========================================================================= #
  def self.start_sinatra_interface
    ::BeautifulUrl::App.run!
  end
    
  # ========================================================================= #
  # === BeautifulUrl::App[]
  # ========================================================================= #
  def self.[](i = '')
    new(i)
  end

end; end

if __FILE__ == $PROGRAM_NAME
  BeautifulUrl::App.start_sinatra_interface
end # beautiful_url_app